library(shiny)

shinyServer(function(input, output) {

    red <- paste("<font color=\"red\">")             
    blue <- paste("<font color=\"blue\">")           
    plus1 <- paste("<font size=\"+0\">")           

    digits <- reactive({
        if(input$which=="Type I") digits<-3
        if(input$which=="Type II") digits<-4
        if(input$which=="Type III") digits<-5
        if(input$which=="Type IIII") digits<-2
        digits
    })    

    data <- reactive({ 
         if(input$which=="Type I") x <- round(rnorm(input$n,10,3),1)
         if(input$which=="Type II") x <- round(rnorm(input$n,30,5),2)
         if(input$which=="Type III") x <- round(rnorm(input$n,0.5,0.1),3)
         if(input$which=="Type IIII") x <- round(rnorm(input$n,200,50))
         x
    })              
 
  
   output$datatable <- renderText({
      x <- data()
      a <- "<table>"
      k <- 0
      i <- 1
      repeat {
          i <- i+1
          a[i] <-"<Tr>"
          for(j in 1:10) {
              k <- k+1
              if(k>length(x)) break
              a[i] <- paste(a[i],"<Td><strong>",HTML("&nbsp;"),x[k]," </Td>",collapse="")
          }    
          a[i] <- paste(a[i],"</Tr>")
          if(k>length(x)) break
      }    
      a[i+1] <- "</table>"      

      a
   }) 
   
   output$text1 <- renderText({
        x <- data()
        mu <- mean(x)
        x1 <- round(x-mu,digits())
        x2 <- round((x-mu)^2,digits())
            
        "<table border>"
        a2 <- paste("<Tr><Th>",plus1,"&nbsp;&nbsp;x</th><th>",plus1,"&nbsp;&nbsp;",HTML("x-X&#773;"),"</th><th>",plus1,"&nbsp;&nbsp;",HTML("(x-X&#773;)<sup>2</sup>"),"</th></tr>")
        a <- rep("",length(x))
        for(i in 1:length(x)) 
            a[i] <- paste("<Tr><Td align=\"right\">",plus1,"&nbsp;&nbsp;",x[i],
                        "</td><td align=\"right\">",plus1,"&nbsp;&nbsp;",x1[i],
                        "</td><td align=\"right\">",plus1,"&nbsp;&nbsp;",x2[i],"</td></tr>")
        c("<table border>",a2,a,"</table>")    
   })        
   
   output$text2 <- renderText({
        x <- data()
        mu <- mean(x)
        paste("<h4>X&#773; = &sum;x/n = ",sum(x),"/",length(x)," = ", round(mu,digits()),"</h4>")
  })      
  
   output$text3 <- renderText({
        x <- data()
        mu <- mean(x)
        line <- paste("<h4>",HTML("&Sum;(x-X&#773;)<sup>2</sup>"),"=",round(sum((x-mu)^2),digits()),"</h4>")
        line[2] <- paste("<h4>Variance: S<sup>2</sup> =",HTML("&Sum;(x-X&#773;)<sup>2</sup>/(n-1)"),"=",round(sum((x-mu)^2),digits()),"/",length(x)-1,"=",round(sum((x-mu)^2)/(length(x)-1),digits())  ,"</h4>")
        line[3] <- paste("<h4>Standard Deviation: s = &radic;",round(sum((x-mu)^2)/(length(x)-1),digits())," = ",round(sd(x),digits()-1),"</h4>")
        line
  })        
           
  output$text4 <- renderText({
        x <- data()
        n <- length(x)
        sxx <- round(sum(x^2)-sum(x)^2/n,digits())
        sd <- round(sqrt((sum(x^2)-sum(x)^2/n)/(n-1)),digits()-1)
        line <- paste("<h4>Sample size n= ",n,"</h4>")
        line[2] <- paste("<h4>&sum;x = ",sum(x),"</h4>")  
        line[3] <- paste("<h4>&sum;x<sup>2</sup> = ",sum(x^2),"</h4>")  
        line[4] <- paste("<h4>S<sub>xx</sub> = &sum; x<sup>2</sup> - (&sum; x)<sup>2</sup>/n = ",
                      sum(x^2),"-",sum(x),"<sup>2</sup>/",n," = ",
                      sxx,"</h4>")  
        line[5] <- paste("<h4>s = &radic;S<sub>xx</sub>/(n-1) = &radic;(",
                      sxx,"/",n-1,") = ",sd,"</h4>")               
        line               
  })      
  output$explainText <- renderText({ 
        "<h5>Explanation: This demo shows how to calculate a standard deviation </h5>"
        
  })
  
   output$appinfo <- renderText({ 
      HTML("<br>&nbsp;<br>&nbsp;<br>&nbsp;<br>
      <a target=\"_blank\" href=\"http://academic.uprm.edu/wrolke/myapps1.htm#standdev\"><h4>What to do</h4></a><br>
      <h6>Written by: Dr. Wolfgang Rolke<br>Created: 12/4/2014</h6>")
      
  })       
  

})

